#[non_exhaustive]pub enum ShallowCloneError {
SpawnFailed {
vcs_name: VcsName,
binary_path: String,
repo_root: Utf8PathBuf,
source: Error,
},
VcsFailed {
vcs_name: VcsName,
exit_status: String,
stderr: String,
},
Io {
path: Utf8PathBuf,
source: Error,
},
UnexpectedOutput {
vcs_name: VcsName,
stdout: String,
},
}Expand description
An error that occurs while checking for a shallow clone.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
SpawnFailed
Failed to spawn the VCS process.
Fields

repo_root: Utf8PathBufThe working directory where the command was run.
VcsFailed
The VCS command to check for a shallow repository failed.
Fields
Io
An I/O error occurred while checking the shallow-clone marker.
Fields

path: Utf8PathBufThe path being checked when the error occurred.
UnexpectedOutput
The VCS command succeeded but returned unexpected output.