#[non_exhaustive]pub enum MaterializeError {
InvalidPathComponent {
path: Utf8PathBuf,
component: String,
},
NotGitStub {
path: Utf8PathBuf,
},
ReadGitStub {
path: Utf8PathBuf,
error: Error,
},
InvalidGitStub {
path: Utf8PathBuf,
error: GitStubParseError,
},
VcsDetect(VcsDetectError),
ReadContents(ReadContentsError),
ShallowCloneCheck {
repo_root: Utf8PathBuf,
error: ShallowCloneError,
},
ShallowClone {
vcs: VcsName,
repo_root: Utf8PathBuf,
},
CreateDir {
path: Utf8PathBuf,
error: Error,
},
WriteOutput {
path: Utf8PathBuf,
error: AtomicWriteError,
},
}Expand description
Errors that can occur during git stub materialization.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidPathComponent
A path argument contains a non-normal component (e.g., ..,
., /, or a Windows prefix).
Only relative paths with plain file and directory names are accepted.
Fields

path: Utf8PathBufThe full path that failed validation.
NotGitStub
The path does not have a .gitstub extension.
Fields

path: Utf8PathBufThe path that was provided.
ReadGitStub
Failed to read the Git stub.
InvalidGitStub
The git stub has an invalid format.
Fields

path: Utf8PathBufThe path to the Git stub.

error: GitStubParseErrorDetails about the parsing error.
VcsDetect(VcsDetectError)
VCS detection failed.
ReadContents(ReadContentsError)
Failed to read contents from Git.
ShallowCloneCheck
Failed to check whether the repository is a shallow clone.
ShallowClone
The repository is a shallow clone.
CreateDir
Failed to create output directory.
WriteOutput
Failed to write the materialized file.
Fields

path: Utf8PathBufThe path where the write failed.

error: AtomicWriteErrorThe underlying write error.